"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const AwaitControl_1 = require("./AwaitControl");
class AsyncActionControl {
    constructor(label, rawKey, stateActions, options) {
        this.label = label;
        this.rawKey = rawKey;
        this.options = options;
        this.start = stateActions.start;
        this.success = stateActions.success;
        this.failure = stateActions.failure;
        this.cancel = stateActions.cancel;
        this.clear = stateActions.clear;
    }
    getKey(actionId) {
        if (actionId) {
            return `${this.rawKey}_${actionId.toString().toUpperCase()}`;
        }
        return this.rawKey;
    }
    getData(s, actionId) {
        var _a;
        const control = AwaitControl_1.default.getControl();
        const extracted = control.extractState(s);
        const statedAction = extracted(control.keyReducer);
        if (!statedAction) {
            throw new Error(`Reducer ${control.keyReducer} not started.`);
        }
        const stored = statedAction[this.getKey(actionId)];
        if ((!stored || stored.length <= 1) && ((_a = this.options) === null || _a === void 0 ? void 0 : _a.initialValue) !== undefined) {
            return { resultData: this.options.initialValue };
        }
        if (stored) {
            const [state, resultData] = stored;
            return { state, resultData };
        }
        return {};
    }
    getStateValue(state, actionId) {
        return this.getData(state, actionId).state;
    }
    getResultValue(state, actionId) {
        return this.getData(state, actionId).resultData;
    }
    isRunning(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'START';
    }
    wasCancelled(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'CANCEL';
    }
    hasFailure(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'FAILURE';
    }
    isSuccessful(actionId) {
        return (state) => this.getStateValue(state, actionId) === 'SUCCESS';
    }
    getResult(actionId) {
        return (state) => this.getResultValue(state, actionId);
    }
}
exports.default = AsyncActionControl;
