"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_redux_1 = require("react-redux");
function createHook(dispatch, control) {
    const start = (payload, meta) => dispatch(control.start(payload, meta));
    const success = (payload, meta) => dispatch(control.success(payload, meta));
    const cancel = (payload, meta) => dispatch(control.cancel(payload, meta));
    const failure = (payload, meta) => dispatch(control.failure(payload, meta));
    const clear = (meta) => dispatch(control.clear(null, meta));
    const isRunning = (actionId) => react_redux_1.useSelector(control.isRunning(actionId));
    const wasCancelled = (actionId) => react_redux_1.useSelector(control.wasCancelled(actionId));
    const hasFailure = (actionId) => react_redux_1.useSelector(control.hasFailure(actionId));
    const isSuccessful = (actionId) => react_redux_1.useSelector(control.isSuccessful(actionId));
    const result = (actionId) => react_redux_1.useSelector(control.getResult(actionId));
    return {
        start,
        success,
        cancel,
        failure,
        clear,
        isRunning,
        wasCancelled,
        hasFailure,
        isSuccessful,
        result,
    };
}
function useAwaitControl(control) {
    const dispatch = react_redux_1.useDispatch();
    if (Array.isArray(control)) {
        return control.map((_control) => createHook(dispatch, _control));
    }
    return createHook(dispatch, control);
}
exports.default = useAwaitControl;
